@@ -13,5 +13,13 @@ def ImageReturnWidget(query=""):
     return ReturnWidgetInput(kind="ImageReturnWidget", query=query)
 
 
-def StringWidget(query=""):
-    return WidgetInput(kind="StringWidget")
+def StringWidget(as_paragraph=False):
+    return WidgetInput(kind="StringWidget", as_paragraph=as_paragraph)
+
+
+def CustomWidget(hook: str):
+    return WidgetInput(kind="CustomWidget", hook=hook)
+
+
+def CustomReturnWidget(hook: str):
+    return ReturnWidgetInput(kind="CustomReturnWidget", hook=hook)
